# APRSD Admin Web Interface

[![PyPI](https://img.shields.io/pypi/v/aprsd-admin-extension.svg)](https://pypi.org/project/aprsd-admin-extension/)
[![Status](https://img.shields.io/pypi/status/aprsd-admin-extension.svg)](https://pypi.org/project/aprsd-admin-extension/)
[![Python Version](https://img.shields.io/pypi/pyversions/aprsd-admin-extension)](https://pypi.org/project/aprsd-admin-extension)
[![License](https://img.shields.io/pypi/l/aprsd-admin-extension)](https://opensource.org/licenses/Apache%20Software%20License%202.0)

[![Read the documentation at https://aprsd-admin-extension.readthedocs.io/](https://img.shields.io/readthedocs/aprsd-admin-extension/latest.svg?label=Read%20the%20Docs)](https://aprsd-admin-extension.readthedocs.io/)

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

---

> [!WARNING]
> Legal operation of this software requires an amateur radio license and a valid call sign.

> [!NOTE]
> Star this repo to follow our progress! This code is under active development, and contributions are both welcomed and appreciated. See [CONTRIBUTING.md](<https://github.com/hemna/aprsd-admin-extension/blob/master/CONTRIBUTING.md>) for details.


![Admin Interface](./screenshot.png)


## Features

The web Admin interface for the aprsd daemon

## Requirements

This requires aprsd \> 3.4.0

## Installation

You can install *APRSD Admin Interface* via [pip](https://pip.pypa.io/)
from [PyPI](https://pypi.org/):

``` console
$ pip install aprsd-admin-extension
```

## Usage

Please see the [Command-line
Reference](https://aprsd-admin-extension.readthedocs.io/en/latest/usage.html)
for details.

## Contributing

Contributions are very welcome. To learn more, see the [Contributor
Guide](CONTRIBUTING.rst).

## License

Distributed under the terms of the [Apache Software License 2.0
license](https://opensource.org/licenses/Apache%20Software%20License%202.0),
*APRSD Admin Interface* is free and open source software.

## Issues

If you encounter any problems, please [file an
issue](https://github.com/hemna/aprsd-admin-extension/issues) along with
a detailed description.

## Credits

This project was generated from [\@hemna](https://github.com/hemna)\'s
APRSD Extension Python
[Cookiecutter](https://github.com/audreyr/cookiecutter) template.
